@@ -1,4 +1,11 @@
-#!/bin/bash
+#!/usr/bin/env
+
+# Import reusable bits
+pushd $( cd -- "$( dirname -- "${BASH_SOURCE[0]}" )" &> /dev/null && pwd ) > /dev/null
+    . functions.sh
+popd > /dev/null
+
+export ALIRE_OS=$(get_OS)
 
 gprclean -q -r -Palr_env
 
