@@ -7,4 +7,13 @@ export ALR_TESTSUITE_ALLOW=1                  # So `alr` doesn't raise
 export ALIRE_TESTSUITE_ENABLE_LOCAL_TESTS=1   # So they're actually run
 
 clear
-./run.py -M1 "$@"
+
+# Warn if GH_USERNAME is unset
+if [ -z "$GH_USERNAME" ]; then
+    echo "Warning: GH_USERNAME is unset, some tests will be skipped."
+    echo "Continuing in 3 seconds..."
+    sleep 3
+    echo
+fi
+
+./run.py --show-time-info -M1 "$@"
