@@ -6,7 +6,7 @@ from drivers.alr import run_alr
 # from drivers.asserts import assert_eq, assert_match
 
 
-p = run_alr('clean')
+p = run_alr("clean")
 
 
-print('SUCCESS')
+print("SUCCESS")
