@@ -12,11 +12,8 @@ compare(contents('libhello_1.0.0_filesystem'),
         ['libhello_1.0.0_filesystem/alire',
          'libhello_1.0.0_filesystem/alire.toml',
          'libhello_1.0.0_filesystem/alire/alire.lock',
-         'libhello_1.0.0_filesystem/alire/config.toml',
-         'libhello_1.0.0_filesystem/config',
-         'libhello_1.0.0_filesystem/config/libhello_config.ads',
-         'libhello_1.0.0_filesystem/config/libhello_config.gpr',
-         'libhello_1.0.0_filesystem/config/libhello_config.h',
+         'libhello_1.0.0_filesystem/alire/flags',
+         'libhello_1.0.0_filesystem/alire/flags/complete_copy',
          'libhello_1.0.0_filesystem/libhello.gpr',
          'libhello_1.0.0_filesystem/src',
          'libhello_1.0.0_filesystem/src/libhello.adb',
