@@ -1,5 +1,5 @@
 """
-Test that maintainers provide a plausible GitHub login
+Test that maintainers-logins values can't be empty strings
 """
 
 from drivers.alr import run_alr
@@ -10,7 +10,7 @@ p = run_alr('show', 'hello_world',
             complain_on_error=False, debug=False, quiet=True)
 assert_match(
     '.*Loading .*hello_world-0.1.0.toml:.*maintainers-logins:.*'
-    'maintainers-logins must be a valid GitHub login, but got: mr.user\n',
+    'maintainers-logins values must be non-empty\n',
     p.out)
 
 print('SUCCESS')
