@@ -11,8 +11,8 @@ from drivers.asserts import assert_eq, assert_match
 # Check a few commands for unexpected output
 
 # Commands that require session
-assert_match(".*Cannot continue with invalid session:.*"  # skip logging prefix
-             " Could not detect a session folder"
+assert_match(".*Cannot continue without a workspace:.*"  # skip logging prefix
+             " Could not detect an alire.toml manifest"
              " at current or parent locations\n",
              run_alr('with', quiet=False, complain_on_error=False).out)
 
