@@ -15,8 +15,8 @@ start_dir = os.getcwd()
 index_dir = os.path.join(os.getcwd(), "my_index")
 os.mkdir("monoproject.upstream")
 os.chdir("monoproject.upstream")
-init_local_crate("myparent")
-init_local_crate("mychild")
+init_local_crate("myparent", with_maintainer_login=True)
+init_local_crate("mychild", with_maintainer_login=True)
 os.chdir(start_dir)
 commit = init_git_repo("monoproject.upstream")
 
