@@ -2,13 +2,14 @@
 Verify that using manual edition and `alr pin` result in equivalent outputs
 """
 
+import os
+
+from e3.fs import rm
+
 from drivers.alr import run_alr, alr_pin, init_local_crate
 from drivers.asserts import assert_eq
 from drivers.helpers import init_git_repo, git_branch
 
-import os
-import shutil
-
 
 def check_equivalent(crate, path="", url="", commit="", branch=""):
     """
@@ -31,18 +32,18 @@ def check_equivalent(crate, path="", url="", commit="", branch=""):
         if i == 1:
             assert_eq(p[0], p[1])
 
-        # Cleanup
+        # Cleanup (use e3.fs, because shutil.rmtree() fails on links on Windows)
         os.chdir("..")
-        shutil.rmtree("xxx")
+        rm("xxx", recursive=True)
 
 
 # Local pinnable crate
 init_local_crate("yyy", enter=False)
-yyy_path = "../yyy"
+yyy_path = os.path.join(os.getcwd(), "yyy")
 
 # Local pinnable raw project
 os.mkdir("zzz")
-zzz_path = "../zzz"
+zzz_path = os.path.join(os.getcwd(), "zzz")
 
 # Simple pin, no restrictions
 check_equivalent("yyy", path=yyy_path)
@@ -51,8 +52,7 @@ check_equivalent("zzz", path=zzz_path)
 # Prepare repository
 head = init_git_repo("yyy")
 branch = git_branch("yyy")
-os.rename("yyy", "yyy.git")  # to be recognizable as a git url
-url = "../yyy.git"
+url = "git+file:" + yyy_path  # to be recognizable as a git url
 
 # Simple git remote, explicit crate
 check_equivalent(crate="yyy", url=url)
