@@ -36,8 +36,8 @@ Dependencies (direct):
    hello*
 Pins (direct):
    hello = { version='7.7.7' }
-Dependencies (external):
-   hello=7.7.7 (direct,missed,pin=7.7.7) (pinned)
+Dependencies (missing):
+   hello=7.7.7 (direct,missed:unavailable,pin=7.7.7) (pinned)
 Dependencies (graph):
    xxx=0.1.0-dev --> hello*
 """, p.out)
